==> haskell-syb-0.6-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.6
id: syb-0.6-C65vWCsht6A8uLstpQIXyj
key: syb-0.6-C65vWCsht6A8uLstpQIXyj
license: BSD3
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Basics Data.Generics.Instances
    Data.Generics.Aliases Data.Generics.Schemes Data.Generics.Text
    Data.Generics.Twins Data.Generics.Builders Generics.SYB
    Generics.SYB.Basics Generics.SYB.Instances Generics.SYB.Aliases
    Generics.SYB.Schemes Generics.SYB.Text Generics.SYB.Twins
    Generics.SYB.Builders
abi: 9411500a69cd001aaba8bc99d2429ff7
trusted: False
import-dirs: /usr/lib/arm-linux-ghc-8.0.1/syb-0.6-C65vWCsht6A8uLstpQIXyj
library-dirs: /usr/lib/arm-linux-ghc-8.0.1/syb-0.6-C65vWCsht6A8uLstpQIXyj
data-dir: /usr/share/arm-linux-ghc-8.0.1/syb-0.6
hs-libraries: HSsyb-0.6-C65vWCsht6A8uLstpQIXyj
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.6-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.6
id: syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
key: syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
license: BSD3
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Basics Data.Generics.Instances
    Data.Generics.Aliases Data.Generics.Schemes Data.Generics.Text
    Data.Generics.Twins Data.Generics.Builders Generics.SYB
    Generics.SYB.Basics Generics.SYB.Instances Generics.SYB.Aliases
    Generics.SYB.Schemes Generics.SYB.Text Generics.SYB.Twins
    Generics.SYB.Builders
abi: 347e3a28794ae8f88e68a2cca01ce0f2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/syb-0.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/syb-0.6
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/syb-0.6
hs-libraries: HSsyb-0.6-IcoSwlPi2Nx4zSqMmorFPS
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
